# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

<!-- insertion marker -->
## [v1.0.1](https://gitlab.com/lhndev1/virvar/tags/v1.0.1) - 2025-01-16

<small>[Compare with v1.0.0](https://gitlab.com/lhndev1/virvar/compare/v1.0.0...v1.0.1)</small>

## [v1.0.0](https://gitlab.com/lhndev1/virvar/tags/v1.0.0) - 2025-01-16

<small>[Compare with v0.2.7](https://gitlab.com/lhndev1/virvar/compare/v0.2.7...v1.0.0)</small>

### Fixed

- fix: improve test environment reset and validation message handling in test #1 ([9c4736a](https://gitlab.com/lhndev1/virvar/commit/9c4736ad52a15d975d5069141f8d0741b68ec275) by vince06fr).

## [v0.2.7](https://gitlab.com/lhndev1/virvar/tags/v0.2.7) - 2025-01-13

<small>[Compare with v0.2.6](https://gitlab.com/lhndev1/virvar/compare/v0.2.6...v0.2.7)</small>

### Fixed

- fix: update docstring to reflect correct variable quoting in activate script ([963fe0c](https://gitlab.com/lhndev1/virvar/commit/963fe0c336b15310627176bb5a1f6181737ca405) by vince06).

## [v0.2.6](https://gitlab.com/lhndev1/virvar/tags/v0.2.6) - 2025-01-12

<small>[Compare with v0.2.5](https://gitlab.com/lhndev1/virvar/compare/v0.2.5...v0.2.6)</small>

## [v0.2.5](https://gitlab.com/lhndev1/virvar/tags/v0.2.5) - 2025-01-12

<small>[Compare with v0.2.4](https://gitlab.com/lhndev1/virvar/compare/v0.2.4...v0.2.5)</small>

## [v0.2.4](https://gitlab.com/lhndev1/virvar/tags/v0.2.4) - 2025-01-12

<small>[Compare with v0.2.3](https://gitlab.com/lhndev1/virvar/compare/v0.2.3...v0.2.4)</small>

### Fixed

- fix(ci): add verbose output to debug TestPyPI Trusted Publishing issue ([5e2a263](https://gitlab.com/lhndev1/virvar/commit/5e2a263a1cdcd52dd4fea6239fc913ab0b92efcf) by vince06fr).

## [v0.2.3](https://gitlab.com/lhndev1/virvar/tags/v0.2.3) - 2025-01-12

<small>[Compare with v0.2.2](https://gitlab.com/lhndev1/virvar/compare/v0.2.2...v0.2.3)</small>

## [v0.2.2](https://gitlab.com/lhndev1/virvar/tags/v0.2.2) - 2025-01-12

<small>[Compare with v0.2.1](https://gitlab.com/lhndev1/virvar/compare/v0.2.1...v0.2.2)</small>

## [v0.2.1](https://gitlab.com/lhndev1/virvar/tags/v0.2.1) - 2025-01-11

<small>[Compare with v0.2.0](https://gitlab.com/lhndev1/virvar/compare/v0.2.0...v0.2.1)</small>

## [v0.2.0](https://gitlab.com/lhndev1/virvar/tags/v0.2.0) - 2025-01-11

<small>[Compare with v0.1.12](https://gitlab.com/lhndev1/virvar/compare/v0.1.12...v0.2.0)</small>

### Fixed

- fix(ci): move SAST template to global include and fix invalid keys ([84a1364](https://gitlab.com/lhndev1/virvar/commit/84a1364f1062f9416cec9fd60b72374db0867ae2) by Vince S).
- fix(virvar): preserve correct value types when adding environment variables ([dd1b35c](https://gitlab.com/lhndev1/virvar/commit/dd1b35c0312044bd4bb0faf5abdfae4ffe3ec810) by vince06fr).

## [v0.1.12](https://gitlab.com/lhndev1/virvar/tags/v0.1.12) - 2025-01-08

<small>[Compare with v0.1.11](https://gitlab.com/lhndev1/virvar/compare/v0.1.11...v0.1.12)</small>

### Fixed

- fix: correct if-else syntax in validate-version script ([3045979](https://gitlab.com/lhndev1/virvar/commit/3045979b0173b5b952e3605e082e690fbf73492b) by Vince S).

## [v0.1.11](https://gitlab.com/lhndev1/virvar/tags/v0.1.11) - 2025-01-08

<small>[Compare with v0.1.10](https://gitlab.com/lhndev1/virvar/compare/v0.1.10...v0.1.11)</small>

### Fixed

- fix: correct version in pyproject.toml ([10c43f0](https://gitlab.com/lhndev1/virvar/commit/10c43f0109c2467f77e11b64e83548298141cf68) by vince06).
- fix: remove variable in validate-version in pipeline ([0fada84](https://gitlab.com/lhndev1/virvar/commit/0fada84fa0f16b0be05e16144a4475958fcc6b0f) by vince06).

## [v0.1.10](https://gitlab.com/lhndev1/virvar/tags/v0.1.10) - 2025-01-08

<small>[Compare with v0.1.9](https://gitlab.com/lhndev1/virvar/compare/v0.1.9...v0.1.10)</small>

### Fixed

- fix: remove variable in validate-version in pipeline ([65c346f](https://gitlab.com/lhndev1/virvar/commit/65c346f9f21d5d7e20cb3c8ada48a200416d3daf) by vince06).

## [v0.1.9](https://gitlab.com/lhndev1/virvar/tags/v0.1.9) - 2025-01-08

<small>[Compare with v0.1.8](https://gitlab.com/lhndev1/virvar/compare/v0.1.8...v0.1.9)</small>

### Fixed

- fix: correct quote issue in version validation script in pipeline ([095b722](https://gitlab.com/lhndev1/virvar/commit/095b7228f905cb2412de4475cfe30c4f069c9914) by Vince S).

## [v0.1.8](https://gitlab.com/lhndev1/virvar/tags/v0.1.8) - 2025-01-08

<small>[Compare with v0.1.7](https://gitlab.com/lhndev1/virvar/compare/v0.1.7...v0.1.8)</small>

### Fixed

- fix: improve clarity and readability of version validation scrip in pipeline ([6711986](https://gitlab.com/lhndev1/virvar/commit/6711986f4c626ee1c349ccb8253fd0404fdc454e) by Vince S).

## [v0.1.7](https://gitlab.com/lhndev1/virvar/tags/v0.1.7) - 2025-01-08

<small>[Compare with v0.1.6](https://gitlab.com/lhndev1/virvar/compare/v0.1.6...v0.1.7)</small>

### Fixed

- fix: correct syntax for version validation in pipeline ([9f1ec78](https://gitlab.com/lhndev1/virvar/commit/9f1ec78ffc96d5d02aae360fe8019c0639c67e08) by Vince S).

## [v0.1.6](https://gitlab.com/lhndev1/virvar/tags/v0.1.6) - 2025-01-08

<small>[Compare with v0.1.5](https://gitlab.com/lhndev1/virvar/compare/v0.1.5...v0.1.6)</small>

### Fixed

- fix: handle version prefix mismatch in pipeline tag validation ([ab49e47](https://gitlab.com/lhndev1/virvar/commit/ab49e47fb61e108d33b832f765b3b0fa766d2485) by Vince S).

## [v0.1.5](https://gitlab.com/lhndev1/virvar/tags/v0.1.5) - 2025-01-08

<small>[Compare with v0.1.4](https://gitlab.com/lhndev1/virvar/compare/v0.1.4...v0.1.5)</small>

## [v0.1.4](https://gitlab.com/lhndev1/virvar/tags/v0.1.4) - 2025-01-08

<small>[Compare with v0.1.3](https://gitlab.com/lhndev1/virvar/compare/v0.1.3...v0.1.4)</small>

### Fixed

- fix: remove bump2version and handle version validation in pipeline ([172c95d](https://gitlab.com/lhndev1/virvar/commit/172c95dcd97270440d7bc3c054e0c0f27c77e033) by Vince S).
- fix: bump version in pyproject.toml ([3dee989](https://gitlab.com/lhndev1/virvar/commit/3dee9893fae5cdd0355c9111504d9b069a860430) by vince06fr).
- fix: ensure validate-version runs on tag push in GitLab CI/CD pipeline ([86f3f93](https://gitlab.com/lhndev1/virvar/commit/86f3f9343808d983b43e1e239a4c3f12468ae092) by Vince S).
- fix: Ensure validation and SAST steps are executed properly with tags in GitLab CI pipeline. ([dd7066b](https://gitlab.com/lhndev1/virvar/commit/dd7066bd4867df06ece10f76c1d42dd13849774a) by Vince S).

## [v0.1.3](https://gitlab.com/lhndev1/virvar/tags/v0.1.3) - 2025-01-07

<small>[Compare with first commit](https://gitlab.com/lhndev1/virvar/compare/1eaa2a5a4850b2a164a21659cc149e6ee3bcc2b2...v0.1.3)</small>

### Added

- Add link to project's LICENSE ([aef6f3c](https://gitlab.com/lhndev1/virvar/commit/aef6f3ca679d2946dc72a93782d47c9088dcb95c) by vince06fr).
- Add LICENSE ([4e08b7f](https://gitlab.com/lhndev1/virvar/commit/4e08b7fdd00742b0e17a43ebdcfe81a44efc2c48) by Vince S).
- Add link to project's Code of Conduct ([ee345d0](https://gitlab.com/lhndev1/virvar/commit/ee345d0270138715c8c18affb3211ee4549ace75) by vince06fr).
- Add tests for create_fake_env and virvar environment variable addition ([f496c23](https://gitlab.com/lhndev1/virvar/commit/f496c23bebd7672f28469a1cc085d98269940687) by vince06fr).
- add gitignore ([5ca1545](https://gitlab.com/lhndev1/virvar/commit/5ca1545e34db8095d01a208cb96fa8fbf70ea93a) by vince06fr).
- add tests directory and file ([81bd23c](https://gitlab.com/lhndev1/virvar/commit/81bd23c4b9f633af851e1273f0fa0982a0053970) by vince06fr).
- add parser for command line ([b02b952](https://gitlab.com/lhndev1/virvar/commit/b02b9522a7b808303c352f3d13654a3cbfab2b8e) by vince06fr).
- add docstring and comments ([ef42225](https://gitlab.com/lhndev1/virvar/commit/ef42225a8d01ea57b691b066f2e4e34bb10fd382) by vince06fr).

### Fixed

- fix: gitlab-ci.yml syntax ([5172bfb](https://gitlab.com/lhndev1/virvar/commit/5172bfb83a123d8aab63f674a080ee7e04e9efbf) by vince06fr).
- fix: use main function for argument parsing in virvar.py ([8815f7f](https://gitlab.com/lhndev1/virvar/commit/8815f7f9c8e6f5f8cd4a3400d1209511a4865c82) by vince06fr).
- fix: resolve circular import by removing virvar import in virvar.py ([32cb029](https://gitlab.com/lhndev1/virvar/commit/32cb029d5d0667dc0a47d25863190de962b1a157) by vince06fr).
- Fix order of line in the verify change section of README ([5884858](https://gitlab.com/lhndev1/virvar/commit/5884858196110e3d3935587743b15dcf29a91161) by vince06fr).
- Fix hardcoded path to relative path for virtual environment ([2d8d932](https://gitlab.com/lhndev1/virvar/commit/2d8d932b46c51c2e631b24890f59b6376214ec46) by vince06fr).
- fix: rename function 'varvir' to 'virvar' ([e807168](https://gitlab.com/lhndev1/virvar/commit/e80716866a33da006f4c4216eb66594d50fadbb4) by vince06fr).

